@@ -1,3 +1,4 @@
+# pylint: skip-file
 """Declares various functions to assist in testing with :mod:`sqlalchemy`."""
 import asyncio
 import copy
@@ -80,7 +81,7 @@ class AsyncSessionTestCase(unittest.TestCase):
 
     def get_connections(self):
         """Return the list holding all connection names."""
-        return list(dict.keys(unimatrix.ext.orm.conf.DATABASES))
+        return list(unimatrix.ext.orm.conf.DATABASES.keys())
 
     def get_session(self, name='self'):
         """Returns the overridden session factory for `name`."""
@@ -171,7 +172,7 @@ class TestDatabaseManager:
 
         # Loop over the discovered database connections to create the engine
         # objects.
-        for name, opts in dict.items(self.databases):
+        for name, opts in self.databases.items():
             self.engines[name] = engine = opts.as_engine(
                 sqlalchemy.create_engine, echo=True)
             if name == 'self':
@@ -186,7 +187,7 @@ class TestDatabaseManager:
         # TODO: Use the default engine to create the tables. Multi-database
         # support is not fully implemented like Django, but this is good
         # enough for now.
-        for name in dict.keys(self.databases):
+        for name in self.databases.keys():
             engine = self.engines[name]
             self.connections[name] = connection = engine.connect()
             self.transactions[name] = tx = connection.begin()
