@@ -4,6 +4,7 @@ import unittest
 from .. import create_engine
 from .. import destroy_engines
 from .. import ENGINES
+from .. import ASYNC_ENGINES
 from ..conf import load_config
 
 
@@ -19,4 +20,14 @@ class CreateEngineTestCase(unittest.TestCase):
         self.assertEqual(len(ENGINES), 0)
         engine = create_engine('self',
             databases=load_config({'DB_ENGINE': 'sqlite', 'DB_NAME': ':memory:'}))
+        self.assertEqual(len(ASYNC_ENGINES), 0)
         self.assertEqual(len(ENGINES), 1)
+
+    def test_async_registry_is_updated(self):
+        destroy_engines()
+        self.assertEqual(len(ASYNC_ENGINES), 0)
+        engine = create_engine('self',
+            use_async=True,
+            databases=load_config({'DB_ENGINE': 'sqlite', 'DB_NAME': ':memory:'}))
+        self.assertEqual(len(ASYNC_ENGINES), 1)
+        self.assertEqual(len(ENGINES), 0)
